@@ -26,7 +26,7 @@ func sessionCmd() *cobra.Command {
 	cmd := &cobra.Command{
 		Use:     "session",
 		Aliases: []string{"se"},
-		Short:   "Display session",
+		Short:   "Display and manage terminal sessions",
 	}
 	cmd.AddCommand(current())
 	cmd.AddCommand(list())
@@ -36,11 +36,16 @@ func sessionCmd() *cobra.Command {
 }
 
 func list() *cobra.Command {
+	runtimeDir := utils.UptermRuntimeDir()
 	cmd := &cobra.Command{
 		Use:     "list",
 		Aliases: []string{"ls", "l"},
 		Short:   "List shared sessions",
-		Long:    `List shared sessions. Session admin sockets are located in ~/.upterm.`,
+		Long: fmt.Sprintf(`List shared sessions.
+
+Sockets are stored in: %s
+
+This follows the XDG Base Directory Specification ($XDG_RUNTIME_DIR/upterm).`, runtimeDir),
 		Example: `  # List shared sessions:
   upterm session list`,
 		RunE: listRunE,
@@ -60,19 +65,25 @@ func show() *cobra.Command {
 		RunE: infoRunE,
 	}
 
-	cmd.Flags().BoolVar(&flagHideClientIP, "hide-client-ip", false, "Hide client IP addresses from output (auto-enabled in CI environments)")
+	cmd.Flags().BoolVar(&flagHideClientIP, "hide-client-ip", false, "Hide client IP addresses from output (auto-enabled in CI environments).")
 
 	return cmd
 }
 
 func current() *cobra.Command {
+	runtimeDir := utils.UptermRuntimeDir()
 	cmd := &cobra.Command{
 		Use:     "current",
 		Aliases: []string{"c"},
 		Short:   "Display the current terminal session",
-		Long: `Display the current terminal session. By default, this command retrieves the current session from
-the admin socket path specified in the UPTERM_ADMIN_SOCKET environment variable. This environment variable is set upon
-sharing a session with 'upterm host'.`,
+		Long: fmt.Sprintf(`Display the current terminal session.
+
+By default, reads the admin socket path from $UPTERM_ADMIN_SOCKET (automatically set
+when you run 'upterm host').
+
+Sockets are stored in: %s
+
+This follows the XDG Base Directory Specification ($XDG_RUNTIME_DIR/upterm).`, runtimeDir),
 		Example: `  # Display the active session as defined in $UPTERM_ADMIN_SOCKET:
   upterm session current
 
@@ -82,19 +93,16 @@ sharing a session with 'upterm host'.`,
 		RunE:    currentRunE,
 	}
 
-	cmd.PersistentFlags().StringVarP(&flagAdminSocket, "admin-socket", "", currentAdminSocketFile(), "admin unix domain socket (required)")
-	cmd.Flags().BoolVar(&flagHideClientIP, "hide-client-ip", false, "Hide client IP addresses from output (auto-enabled in CI environments)")
+	cmd.PersistentFlags().StringVarP(&flagAdminSocket, "admin-socket", "", currentAdminSocketFile(), "Admin socket path (required).")
+	cmd.Flags().BoolVar(&flagHideClientIP, "hide-client-ip", false, "Hide client IP addresses from output (auto-enabled in CI environments).")
 
 	return cmd
 }
 
 func listRunE(c *cobra.Command, args []string) error {
-	uptermDir, err := utils.CreateUptermDir()
-	if err != nil {
-		return err
-	}
+	runtimeDir := utils.UptermRuntimeDir()
 
-	sessions, err := listSessions(uptermDir)
+	sessions, err := listSessions(runtimeDir)
 	if err != nil {
 		return err
 	}
@@ -142,12 +150,8 @@ func infoRunE(c *cobra.Command, args []string) error {
 		return fmt.Errorf("missing session name")
 	}
 
-	uptermDir, err := utils.UptermDir()
-	if err != nil {
-		return err
-	}
-
-	return displaySessionFromAdminSocketPath(filepath.Join(uptermDir, host.AdminSocketFile(args[0])))
+	runtimeDir := utils.UptermRuntimeDir()
+	return displaySessionFromAdminSocketPath(filepath.Join(runtimeDir, host.AdminSocketFile(args[0])))
 }
 
 func currentRunE(c *cobra.Command, args []string) error {
@@ -332,11 +336,15 @@ func validateCurrentRequiredFlags(c *cobra.Command, args []string) error {
 func displayAuthorizedKeys(keys []*api.AuthorizedKey) string {
 	var aks []string
 	for _, ak := range keys {
-		var fps []string
-		for _, fp := range ak.PublicKeyFingerprints {
-			fps = append(fps, fmt.Sprintf("- %s", fp))
+		if len(ak.PublicKeyFingerprints) == 0 {
+			aks = append(aks, fmt.Sprintf("[!] %s (no SSH keys configured)", ak.Comment))
+		} else {
+			var fps []string
+			for _, fp := range ak.PublicKeyFingerprints {
+				fps = append(fps, fmt.Sprintf("- %s", fp))
+			}
+			aks = append(aks, fmt.Sprintf("%s:\n%s", ak.Comment, strings.Join(fps, "\n")))
 		}
-		aks = append(aks, fmt.Sprintf("%s:\n%s", ak.Comment, strings.Join(fps, "\n")))
 	}
 
 	return strings.Join(aks, "\n")
